==> qtjambi-uic-6.3.0-sources.jar: io/qt/uic/ui4/DomTime.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomTime</p>
 */
public class DomTime extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomTime(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomTime instance);
    
    @io.qt.QtUninvokable
    public final void clearElementHour(){
        clearElementHour_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementHour_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementMinute(){
        clearElementMinute_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementMinute_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementSecond(){
        clearElementSecond_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementSecond_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementHour(){
        return elementHour_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementHour_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementMinute(){
        return elementMinute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementMinute_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final int elementSecond(){
        return elementSecond_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native int elementSecond_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementHour(){
        return hasElementHour_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementHour_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementMinute(){
        return hasElementMinute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementMinute_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementSecond(){
        return hasElementSecond_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementSecond_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementHour(int a){
        setElementHour_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementHour_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementMinute(int a){
        setElementMinute_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementMinute_native_int(long __this__nativeId, int a);
    
    @io.qt.QtUninvokable
    public final void setElementSecond(int a){
        setElementSecond_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementSecond_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = ""</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, "");
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomTime(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-uic-6.5.2-sources.jar: io/qt/uic/ui4/DomTime.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>DomTime</code></p>
 */
public class DomTime extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomTime::<wbr>DomTime()</code></p>
     */
    public DomTime(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomTime instance);
    
    /**
     * <p>See <code>DomTime::<wbr>clearElementHour()</code></p>
     */
    @QtUninvokable
    public final void clearElementHour(){
        clearElementHour_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementHour_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomTime::<wbr>clearElementMinute()</code></p>
     */
    @QtUninvokable
    public final void clearElementMinute(){
        clearElementMinute_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementMinute_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomTime::<wbr>clearElementSecond()</code></p>
     */
    @QtUninvokable
    public final void clearElementSecond(){
        clearElementSecond_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementSecond_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomTime::<wbr>elementHour()const</code></p>
     */
    @QtUninvokable
    public final int elementHour(){
        return elementHour_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementHour_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomTime::<wbr>elementMinute()const</code></p>
     */
    @QtUninvokable
    public final int elementMinute(){
        return elementMinute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementMinute_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomTime::<wbr>elementSecond()const</code></p>
     */
    @QtUninvokable
    public final int elementSecond(){
        return elementSecond_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native int elementSecond_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomTime::<wbr>hasElementHour()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementHour(){
        return hasElementHour_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementHour_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomTime::<wbr>hasElementMinute()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementMinute(){
        return hasElementMinute_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementMinute_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomTime::<wbr>hasElementSecond()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementSecond(){
        return hasElementSecond_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementSecond_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomTime::<wbr>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomTime::<wbr>setElementHour(int)</code></p>
     */
    @QtUninvokable
    public final void setElementHour(int a){
        setElementHour_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementHour_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomTime::<wbr>setElementMinute(int)</code></p>
     */
    @QtUninvokable
    public final void setElementMinute(int a){
        setElementMinute_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementMinute_native_int(long __this__nativeId, int a);
    
    /**
     * <p>See <code>DomTime::<wbr>setElementSecond(int)</code></p>
     */
    @QtUninvokable
    public final void setElementSecond(int a){
        setElementSecond_native_int(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementSecond_native_int(long __this__nativeId, int a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    /**
     * <p>See <code>DomTime::<wbr>write(QXmlStreamWriter&amp;,<wbr>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomTime(QPrivateConstructor p) { super(p); } 
    
}
